Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1198)

Unified Diff: tests/StreamTest.cpp

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/SmallAllocatorTest.cpp ('k') | tests/StringTest.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/StreamTest.cpp
diff --git a/tests/StreamTest.cpp b/tests/StreamTest.cpp
index 6f78eca5f0de6c4554db514ccad9c0fbb9138e38..d307f513183e4c520005c3e569cb936eb9a509d9 100644
--- a/tests/StreamTest.cpp
+++ b/tests/StreamTest.cpp
@@ -170,16 +170,16 @@ static void TestPackedUInt(skiatest::Reporter* reporter) {
}
}
// Test that setting an SkMemoryStream to a NULL data does not result in a crash when calling
// methods that access fData.
static void TestDereferencingData(SkMemoryStream* memStream) {
- memStream->read(NULL, 0);
+ memStream->read(nullptr, 0);
memStream->getMemoryBase();
SkAutoDataUnref data(memStream->copyToData());
}
static void TestNullData() {
- SkData* nullData = NULL;
+ SkData* nullData = nullptr;
SkMemoryStream memStream(nullData);
TestDereferencingData(&memStream);
@@ -241,9 +241,9 @@ static void test_peeking_front_buffered_stream(skiatest::Reporter* r,
const SkStream& original,
size_t bufferSize) {
SkStream* dupe = original.duplicate();
- REPORTER_ASSERT(r, dupe != NULL);
+ REPORTER_ASSERT(r, dupe != nullptr);
SkAutoTDelete<SkStream> bufferedStream(SkFrontBufferedStream::Create(dupe, bufferSize));
- REPORTER_ASSERT(r, bufferedStream != NULL);
+ REPORTER_ASSERT(r, bufferedStream != nullptr);
test_peeking_stream(r, bufferedStream, bufferSize);
}
« no previous file with comments | « tests/SmallAllocatorTest.cpp ('k') | tests/StringTest.cpp » ('j') | no next file with comments »
@@ -170,16 +170,16 @@ static void TestPackedUInt(skiatest::Reporter* reporter) {
}
}
-// Test that setting an SkMemoryStream to a NULL data does not result in a crash when calling
+// Test that setting an SkMemoryStream to a nullptr data does not result in a crash when calling
// methods that access fData.
static void TestDereferencingData(SkMemoryStream* memStream) {

Powered by Google App Engine
This is Rietveld 408576698